import { DEFAULT_LAYOUT } from '../base';
import { AppRouteRecordRaw } from '../types';

const IOT: AppRouteRecordRaw = {
  path: '/iot',
  name: 'iot',
  component: DEFAULT_LAYOUT,
  meta: {
    locale: 'menu.iot',
    title: '物联网管理',
    icon: 'icon-empty',
    requiresAuth: true,
    order: 1,
    permissions: ['iot'],
  },
  children: [
    {
      path: 'product',
      name: 'Product',
      component: () => import('@/views/iot/product/index.vue'),
      meta: {
        locale: 'menu.system.product',
        title: '产品管理',
        requiresAuth: true,
        permissions: ['iot:product'],
      },
    },
    {
      path: 'device',
      name: 'Device',
      component: () => import('@/views/iot/device/index.vue'),
      meta: {
        locale: 'menu.system.device',
        title: '设备管理',
        requiresAuth: true,
        permissions: ['iot:device'],
      },
    },
    {
      path: 'product/:id',
      name: 'productDetail',
      component: () => import('@/views/iot/product/components/product-detail.vue'),
      meta: {
        locale:'menu.system.product',
        title: '产品详情',
        requiresAuth: true,
        showInMenu: false,
        permissions: ['iot:product:query'],
      },
    },
    {
      path: 'device/:id',
      name: 'deviceDetail',
      component: () => import('@/views/iot/device/components/device-detail.vue'),
      meta: {
        locale: 'menu.system.deviceDetail',
        title: '设备详情',
        requiresAuth: true,
        showInMenu: false,
        permissions: ['iot:device:query'],
      },
    },
    {
      path: 'product/tsl/:id',
      name: 'productTsl',
      component: () => import('@/views/iot/product/components/product-tsl.vue'),
      meta: {
        locale: 'menu.system.productTsl',
        title: '物模型',
        requiresAuth: true,
        showInMenu: false,
        permissions: ['iot:tsl'],
      },
    }

  ],
};

export default IOT;
